%% Flip a dataset in the Z direction
function [OutCellArray, OutConfig] = FlipZ(InCellArray, InConfig)
% This module reverses the sign of the data in the dataset.  This operation
% is equivalent to flipping the data in the Z axis.  It can operate on Map,
% FreqMap and LayerMap datatypes.  All headers are preserved.  Note that the
% order of layers in a LayerMap is not changed.
%
% Inputs: Map or FreqMap or LayerMap
% Outputs: Same datatype as input
%
% Author: Adrian Loeff
% Email: aloeff@optics.arizona.edu
%
% Version History:
% 2012/11/16 ARL - Created.

    % Use the inputs as the default outputs
    OutConfig = InConfig;
    OutCellArray = InCellArray;

    % Only handle certain types of datasets
    if ~strcmpi(InCellArray{1}.type, 'map') && ...
       ~strcmpi(InCellArray{1}.type, 'freqmap') && ...
       ~strcmpi(InCellArray{1}.type, 'layermap')
        % Dataset type is not supported - do nothing
        return;    
    end

    % Negate the input data to produce the output data
    OutCellArray{1}.data = -real(InCellArray{1}.data);
end
