function [OutCellArray, Outconfig]=MapArithmetic(InCellArray, Inconfig)
%MapArithmetic allows the arithmatic (-,+,*,/) manipulation of map data.
%Inputs include a numeric value, and the operation to be performed.
%
%Inputs: Map
%Outputs: Map
%
%Author: Benjamin Lewis
%Email: blewis@email.arizona.edu
%
% Version history:
% 8/18/10 - Version 0.5
% 8/20/11 - version 0.6 by Dae Wook Kim letter2dwk@hotmail.com (additional
% description)

Outconfig=Inconfig;

OutCellArray{1}=InCellArray{1};

InitSelection=Inconfig{strcmpi(Inconfig, 'Operation'),2};
InitValue=Inconfig{strcmpi(Inconfig, 'Value'),2};

validinputs=0;

while ~validinputs %get a number from user
    answers = inputdlg({'Enter a numeric value:'},'MapArithmetic',1,{InitValue});
    if ~isempty(answers)
        tempval=answers{:};
        tempval=str2num(tempval);
        if ~isempty(tempval)
            validinputs=1;
            ArithVal=tempval;
        else
            msgbox('Please enter valid inputs','Invalid Inputs','warn','modal')
        end
    else
        OutCellArray={};
        return; %If answers is empty, user canceled
    end
end

switch InitSelection
    case '-'
        InitSelection=1;
    case '+'
        InitSelection=2;
    case '*'
        InitSelection=3;
    case '/'
        InitSelection=4;
    otherwise
        InitSelection=1;
end

[selection, ok] = listdlg('Name', 'MapCombine', 'PromptString','Select an Operation:', ...
    'SelectionMode','single','ListString',{'-', '+', '*', '/'}, 'InitialValue', InitSelection);

if ~ok, return; end %user canceled

switch selection %execute operation
    case 1
        OutCellArray{1}.data=InCellArray{1}.data-ArithVal;
        Operation='-';
    case 2
        OutCellArray{1}.data=InCellArray{1}.data+ArithVal;
        Operation='+';
    case 3
        OutCellArray{1}.data=InCellArray{1}.data.*ArithVal;
        Operation='*';
    case 4
        OutCellArray{1}.data=InCellArray{1}.data./ArithVal;
        Operation='/';
    otherwise
        OutCellArray{1}.data=InCellArray{1}.data-ArithVal;
        Operation='-';        
end
    
Outconfig{strcmpi(Outconfig, 'Operation'),2}=Operation;
Outconfig{strcmpi(Outconfig, 'Value'),2}=num2str(ArithVal);

end

