function [OutCellArray, Outconfig]=MapCombine(InCellArray, Inconfig)
% Two maps with identical size and identical array dimensions are combined
% into a single map using simple arithmetic such as add, subtract, multiply
% or divide.
%
%Inputs: Two Maps
%Outputs: Combined map
%
%Author: Benjamin Lewis
%Email: blewis@email.arizona.edu
%
% Version history:
% 11/7/11 - Version 2

Outconfig=Inconfig;

if any(size(InCellArray{1}.data)~=size(InCellArray{2}.data))
    errordlg('Map Array Size Mismatch!  Maps can not be combined.','MapCombine','modal');
    OutCellArray={};
    return;
end

OutCellArray{1}.header={'Date Created', ''};

loopstr={'x','y','z'};

tsize.x{1}=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'X Size'),2};
tsize.x{2}=InCellArray{1}.header{strcmpi(InCellArray{2}.header, 'X Size'),2};

tsize.y{1}=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'Y Size'),2};
tsize.y{2}=InCellArray{1}.header{strcmpi(InCellArray{2}.header, 'Y Size'),2};


for ii=1:2
    if str2num(tsize.(loopstr{ii}){1})~=str2num(tsize.(loopstr{ii}){2})
        sizedefault=Inconfig{strcmpi(Inconfig, [upper(loopstr{ii}),'Size Mismatch']),2};
        
        if strcmpi(sizedefault,'1')
            sizedefault=['1 (',tsize.(loopstr{ii}){1},')'];
        elseif strcmpi(sizedefault,'2')
            sizedefault=['2 (',tsize.(loopstr{ii}){2},')'];
        end
        
        
        sizedefault=questdlg([upper(loopstr{ii}),'Size Mismatch, which size should be used as the radius of the data?:'],'MapCombine',...
            ['1 (',tsize.(loopstr{ii}){1},')'],['2 (',tsize.(loopstr{ii}){2},')'],'Other',sizedefault);

        if strcmpi(sizedefault,['1 (',tsize.(loopstr{ii}){1},')'])
            sizedefault='1';
        elseif strcmpi(sizedefault,['2 (',tsize.(loopstr{ii}){2},')'])
            sizedefault='2';
        end
        
        Outconfig{strcmpi(Outconfig, [upper(loopstr{ii}),'Size Mismatch']),2}=sizedefault;
        
        switch sizedefault
            case ['1 (',tsize.(loopstr{ii}){1},')']
                tsize.(loopstr{ii})=str2num(tsize.(loopstr{ii}){1});
            case ['2 (',tsize.(loopstr{ii}){2},')']
                tsize.(loopstr{ii})=str2num(tsize.(loopstr{ii}){2});
            case 'Other'
                temps=Inconfig{strcmpi(Inconfig, [upper(loopstr{ii}),'Size']),2};
                
                validinputs=0;
                
                %Get user input
                while ~validinputs
                    answers = inputdlg({[upper(loopstr{ii}),'Size:']},'MapCombine',1,{temps});
                    if ~isempty(answers)
                        temps=answers{:};
                        temps=str2num(temps);
                        if ~isempty(temps)
                            validinputs=1;
                            tsize.(loopstr{ii})=temps;
                        else
                            msgbox('Please enter valid inputs','Invalid Inputs','warn','modal')
                        end
                    else
                        OutCellArray={};
                        return; %If answers is empty, user canceled
                    end
                end
                
                Outconfig{strcmpi(Outconfig, [upper(loopstr{ii}),'Size']),2}=num2str(tsize.(loopstr{ii}));
        end
    else
        tsize.(loopstr{ii})=str2num(tsize.(loopstr{ii}){1});
    end
end

OutCellArray{1}.header(end+1,:)={'X Size', num2str(tsize.x)};
OutCellArray{1}.header(end+1,:)={'Y Size', num2str(tsize.y)};



tunit.x{1}=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'X Unit'),2};
tunit.x{2}=InCellArray{1}.header{strcmpi(InCellArray{2}.header, 'X Unit'),2};
tunit.y{1}=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'Y Unit'),2};
tunit.y{2}=InCellArray{1}.header{strcmpi(InCellArray{2}.header, 'Y Unit'),2};
tunit.z{1}=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'Z Unit'),2};
tunit.z{2}=InCellArray{1}.header{strcmpi(InCellArray{2}.header, 'Z Unit'),2};


for ii=1:3
    if tunit.(loopstr{ii}){1}~=tunit.(loopstr{ii}){2}
        sizedefault=Inconfig{strcmpi(Inconfig, [upper(loopstr{ii}),'Unit Mismatch']),2};
        
        if strcmpi(sizedefault,'1')
            sizedefault=['1 (',tunit.(loopstr{ii}){1},')'];
        elseif strcmpi(sizedefault,'2')
            sizedefault=['2 (',tunit.(loopstr{ii}){2},')'];
        end
        
        
        sizedefault=questdlg([upper(loopstr{ii}),'Unit Mismatch, which unit should be used as the radius of the data?:'],'MapCombine',...
            ['1 (',tunit.(loopstr{ii}){1},')'],['2 (',tunit.(loopstr{ii}){2},')'],'Other',sizedefault);

        if strcmpi(sizedefault,['1 (',tunit.(loopstr{ii}){1},')'])
            sizedefault='1';
        elseif strcmpi(sizedefault,['2 (',tunit.(loopstr{ii}){2},')'])
            sizedefault='2';
        end
        
        Outconfig{strcmpi(Outconfig, [upper(loopstr{ii}),'Unit Mismatch']),2}=sizedefault;
        
        switch sizedefault
            case ['1 (',tunit.(loopstr{ii}){1},')']
                tunit.(loopstr{ii})=tunit.(loopstr{ii}){1};
            case ['2 (',tunit.(loopstr{ii}){2},')']
                tunit.(loopstr{ii})=tunit.(loopstr{ii}){2};
            case 'Other'
                tunit=Inconfig{strcmpi(Inconfig, [upper(loopstr{ii}),'Unit']),2};
                
                answers = inputdlg({[upper(loopstr{ii}),'Unit']},'MapCombine',1,{tunit});
                if ~isempty(answers)
                    tunit.(loopstr{ii})=answers{:};
                else
                    OutCellArray={};
                    return; %If answers is empty, user canceled
                end                
                
                Outconfig{strcmpi(Outconfig, [upper(loopstr{ii}),'Unit']),2}=num2str(tunit.(loopstr{ii}));
        end
    else
        tunit.(loopstr{ii})=tunit.(loopstr{ii}){1};
    end
end

OutCellArray{1}.header(end+1,:)={'X Unit', num2str(tunit.x)};
OutCellArray{1}.header(end+1,:)={'Y Unit', num2str(tunit.y)};
OutCellArray{1}.header(end+1,:)={'Z Unit', num2str(tunit.z)};

if ~strcmpi(InCellArray{1}.name,InCellArray{2}.name)
    OutCellArray{1}.name=strcat(InCellArray{1}.name, InCellArray{2}.name);
else
    OutCellArray{1}.name=InCellArray{1}.name;
end

OutCellArray{1}.modulecount=max(InCellArray{1}.modulecount, InCellArray{2}.modulecount);

OutCellArray{1}.log=[InCellArray{1}.log, InCellArray{2}.log];

OutCellArray{1}.type='map';

dmap1=InCellArray{1}.data;
dmap2=InCellArray{2}.data;



f=figure('units','pixels','position',[200,200,810,270]);
set(f,'name','MapCombine','HandleVisibility','off','menubar','none','NumberTitle','off', ...
    'resize','off','visible','off','KeyPressFcn',@keypress);


str1='Dataset 1';
str2='Dataset 2';

h(1)=uicontrol('style','pushbutton','parent',f,'units','pixels','position',[610,226,180,22],'string',[str1,' + ',str2],'callback',@Button_callback);
h(2)=uicontrol('style','pushbutton','parent',f,'units','pixels','position',[610,184,180,22],'string',[str1,' * ',str2],'callback',@Button_callback);
h(3)=uicontrol('style','pushbutton','parent',f,'units','pixels','position',[610,146,180,22],'string',[str1,' - ',str2],'callback',@Button_callback);
h(4)=uicontrol('style','pushbutton','parent',f,'units','pixels','position',[610,104,180,22],'string',[str2,' - ',str1],'callback',@Button_callback);
h(5)=uicontrol('style','pushbutton','parent',f,'units','pixels','position',[610,62,180,22],'string',[str1,' / ',str2],'callback',@Button_callback);
h(6)=uicontrol('style','pushbutton','parent',f,'units','pixels','position',[610,20,180,22],'string',[str2,' / ',str1],'callback',@Button_callback);

ax1=axes('parent',f,'Units','Pixels','Position',[40,40,245,190]);
ax2=axes('parent',f,'Units','Pixels','Position',[325,40,245,190]);

set(f,'visible','on');

formatedmodulecount=num2str(InCellArray{1}.modulecount, '%02.0f');
if numel(InCellArray{1}.log) > 0, lastName = ['_',InCellArray{1}.log{end}]; else lastName = ''; end
dataName1 = strcat('Mx', formatedmodulecount, '_', InCellArray{1}.name, '_', ...
    InCellArray{1}.type, lastName);
imagesc(dmap1,'alphadata',~isnan(dmap1),'parent',ax1);
%text(86,86,'1','parent',ax1,'fontsize',16);
colorbar('peer',ax1);
title(ax1,{'Dataset 1';dataName1},'Interpreter', 'none');

formatedmodulecount=num2str(InCellArray{2}.modulecount, '%02.0f');
if numel(InCellArray{2}.log) > 0, lastName = ['_',InCellArray{2}.log{end}]; else lastName = ''; end
dataName2 = strcat('Mx', formatedmodulecount, '_', InCellArray{2}.name, '_', ...
    InCellArray{2}.type, lastName);
imagesc(dmap2,'alphadata',~isnan(dmap2),'parent',ax2);
%text(86,86,'2','parent',ax2,'fontsize',16);
colorbar('peer',ax2);
title(ax2,{'Dataset 2';dataName2},'Interpreter', 'none');


button=0;

movegui(f,'center');

op=str2num(Inconfig{strcmpi(Inconfig, 'Operation'),2});
if op<1, op=1; end     % handle case where user cancelled last time

uicontrol(h(op));

uiwait(f);

if ishandle(f), delete(f); end

Outconfig{strcmpi(Outconfig, 'Operation'),2}=num2str(button);

switch button
    case 1
        OutCellArray{1}.data=dmap1+dmap2;
    case 2
        OutCellArray{1}.data=dmap1.*dmap2;
    case 3
        OutCellArray{1}.data=dmap1-dmap2;
    case 4
        OutCellArray{1}.data=dmap2-dmap1;
    case 5
        OutCellArray{1}.data=dmap1./dmap2;
    case 6
        OutCellArray{1}.data=dmap2./dmap1;
    case 0
        OutCellArray={};
        
end


    function Button_callback(hObject, ~)        
        button=find(h==hObject);
        if isempty(button)
            button=0;
        end
        if ishandle(f), delete(f); end
    end


    function keypress(~, evd)
        switch(evd.Key)
            case {'return','space'}
                button=find(h==hObject);
                if isempty(button)
                    button=0;
                end
                if ishandle(f), delete(f); end
        end
    end

end
