function [OutCellArray, Outconfig]=ZeroPadding(InCellArray, Inconfig)
%ZeroPadding pads input array with zeros and replaces any NaNs in the array
% with zeros. Padsize is a positive integers that specifies the amount of
% padding to add.
%
%Inputs: Map
%Outputs: Map
%
%Author: Ping Zhou
%Email:
%
% Version history:
% 9/10/10 - Version 1
% 2/1/12 - Version 1.1 - Check the size of map before operation.

OutCellArray{1}=InCellArray{1};

DiameterX=str2double(InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'X Size'),2});
DiameterY=str2double(InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'Y Size'),2});

[ptsY, ptsX] = size(InCellArray{1}.data);

Outconfig=Inconfig;

validinputs=0;
Padsize=Inconfig{strcmpi(Inconfig, 'Padsize'),2};

%Get user input on the padsize
while ~validinputs
    answers = inputdlg({'The padsize:'},'Input for padsize',1,{num2str(Padsize)});
    if ~isempty(answers)
        tempPadsize=answers{:};        
        tempPadsize=str2double(tempPadsize);
        if ~isempty(tempPadsize)
            validinputs=1;           
            Padsize=tempPadsize;
        else
            msgbox('Please enter valid inputs','Invalid Inputs','warn','modal')
        end
        
    else
        OutCellArray={};
        return; %If answers is empty, user canceled
    end
end


% Check size of map
% if (ptsX == 1 || ptsY == 1)
%     msgbox('Map is a 1D array. Treating one dimension as full width.', 'Invalid Inputs','warn','modal') 
%     if ptsX == 1
%         ptsX = 2;
%     end
%     if ptsY == 1
%         ptsY = 2;
%     end
% end

% Calculate old pixel spacing
delx = DiameterX; % / (ptsX - 1);
dely = DiameterY; % / (ptsY - 1);

% Replace NaN's in data with zeros (questionable?)
data = InCellArray{1}.data;
data(isnan(data))=0;

% Pad the data array
data_padded = padarray(data, [Padsize Padsize]);
OutCellArray{1}.data=data_padded;

% Calculate the new size
[ptsY, ptsX] = size(OutCellArray{1}.data);

% Calculate new diameters
NewDiameterX = delx; % * (ptsX - 1);
NewDiameterY = dely; % * (ptsY - 1);

% Write new diameters out to the header
OutCellArray{1}.header{strcmpi(OutCellArray{1}.header, 'X Size'),2}=num2str(NewDiameterX);
OutCellArray{1}.header{strcmpi(OutCellArray{1}.header, 'Y Size'),2}=num2str(NewDiameterY);

% Updating the Padsize configuration variable
Outconfig{strcmpi(Outconfig, 'Padsize'),2}=num2str(Padsize);

