function [OutCellArray,Outconfig]=ManyInputs(InCellArray, Inconfig)
% MANYINPUTS is a template module that takes a variable number of inputs.
%
% ManyInputs does not perform any action. It is intended to show an
% example of a module which can operate on a variable number of inputs
% In this example, the types are 'map' or 'mask' data types and the output
% will be the sum of the individual inputs.
%
% Note: This module will NOT APPEAR IN SAGUARO. To practice using it, place
% a copy of the .m file and the associated .txt file in the 'UserModules'
% directory. To activate it within SAGUARO, multiple map (or mask) data
% sets must be selected simultaneously. This can be accomplished by holding
% down the <Ctrl> key while selecting two or more previously
% loaded/generated data sets.
%
% Note: The associated ManyInputs.txt file contains the following
% lines which are at the heart of this module functionality:
%                   Map, 2+, General
%                   Mask, 2+, General
% Each line has three parts. The first part describes the data type that
% can be used by this module. In this example, either 'Map' or 'Mask' data
% types can be computed.
%
% The second element of each line describes how many inputs are used. For
% this example, '2+' indicates any any number of maps or masks can be used
% as long as there are at least 2 of them.
%
% Note that when the plus is included in the quantity description, then all
% inputs are sent simultaneously. If the quantity was only '2' (without the
% plus), then SAGUARO would break them up into groups of two and act on
% them separately. In other words, without the plus sign indicator in the
% quantity description, SAGUARO will consider that you want to "batch
% process" the selection of data by making multiple calls to the module
% instead of sending them all in at once.
%
% The third value in each line of the text file describes the category
% the module fits into. In this case, the module can be found under the
% 'General' category. This categorization is useful for quickly finding
% modules in SAGUARO by using the sort feature.
%
% Inputs: two or more data sets of the same type (map or mask)
% Outputs: one data type of the same type as the input (map or mask)
%
% Author: Greg Smith
% Email: gsmith@optics.arizona.edu
%
% Version history:
% 2012/06/20 - Version 1.0

% default values (in case something happens) will be the first data set
Outconfig=Inconfig;
OutCellArray{1}=InCellArray{1};

% Process each and every data set that is passed in. Because the number of
% data sets is not known ahead of time, they are processed in a 'for' loop.
% In this example, a running total is computed.
dataSum = InCellArray{1}.data;
for dataCount = 2:length(InCellArray)
    currentData = InCellArray{dataCount}.data;
    dataSum = dataSum + currentData;
end

% set output data
OutCellArray{1}.data = dataSum;
end


