function [OutCellArray, OutConfig] = ZeroInput(~,~)
% ZEROINPUT is a template module that takes no inputs.
%
% ZeroInput is a template module which does not perform anything. It is
% intended to show an example of a module which takes no inputs from
% SAGUARO. Instead, it queries the user to find a particular file to oen.
% It reads that file and processes the data into a 'coordinates' data type.
%
% This module is intended to demonstrate how modules can be created to read
% in non-standard data.
%
% Note: The associated ZeroInput.txt file contains the following line:
%                   Tools, 0, Conversion
% The 'Tools' describes the input data type. All modules which are of type
% 'Tools' are ALWAYS available. The '0' (zero) value indicates the number of
% input data sets required. This example loads new data and therefore does
% not require any input data. The 'Conversion' specifier is an identifier
% that can be used to sort the modules. This module will appear in the
% 'Conversion' category in SAGUARO.
%
% Inputs: None
% Outputs: Coordinates
%
% Author: Greg Smith
% Email: gsmith@optics.arizona.edu
%
% Version history:
% 2012/05/30 - Version 1.0

    % set default values to be saved in configuration file
    defaultUnit = 'unknown';
    unitList = {'Date','Time','unitsA','unitsA'};
    delimiter = '\t';
    
    % create default config file information
    unitListString = sprintf('%s,',unitList{:});
    unitListString = unitListString(1:end-1);
    OutConfig = {'delimiter',delimiter;
        'defaultUnit',defaultUnit;
        'unitList',unitListString;
        };
    
    % create default output data with appropriate headers
    % there is only one output, so fill in 1st cell array of OutCellArray
    OutCellArray{1}.name = 'ZeroInput_Module_Data';
    OutCellArray{1}.moduleCount = 0;
    OutCellArray{1}.type = 'coordinates';
    OutCellArray{1}.header = {
        'Date Created',datestr(now,'mm/dd/yy HH:MM PM');
        'Column unit','unitsA, unitsB, unitsC';
        'Column Label','LabelA, LabelB, LabelC'};
    OutCellArray{1}.data = [];
    OutCellArray{1}.property = cell(0,2);
    OutCellArray{1}.log = struct();
    
    
    %% Get data from user
    myData = uiimport;
    
    %% update OutCellArray and OutConfig values based on data
    % This would be the place where you could put processing code that
    % extracts relevant OutCellArray and OutConfig values and places them
    % into the actual output. Right now, the default values are returned no
    % matter what the user selects to import.
    
end